@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -67,6 +67,7 @@ import com.openexchange.mail.service.MailService;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountStorageService;
+import com.openexchange.mailaccount.MailAccounts;
 import com.openexchange.server.ExceptionOnAbsenceServiceLookup;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
@@ -190,6 +191,19 @@ public class EmailContactHalo extends AbstractContactHalo implements HaloContact
         return "com.openexchange.halo.mail";
     }
 
+    private static final Comparator<MailMessage> MAIL_COMPARATOR = new Comparator<MailMessage>() {
+
+        @Override
+        public int compare(final MailMessage m1, final MailMessage m2) {
+            final Date sentDate1 = m2.getSentDate();
+            final Date sentDate0 = m1.getSentDate();
+            if (sentDate1 == null) {
+                return null == sentDate0 ? 0 : -1;
+            }
+            return null == sentDate0 ? 1 : sentDate1.compareTo(sentDate0);
+        }
+    };
+
     @Override
     public AJAXRequestResult investigate(final HaloContactQuery query, final AJAXRequestData req, final ServerSession session) throws OXException {
         MailService mailService = services.getService(MailService.class);
@@ -201,6 +215,7 @@ public class EmailContactHalo extends AbstractContactHalo implements HaloContact
             requestedFields = MailField.getFields(columnCollection.getFields());
             headers = columnCollection.getHeaders();
         }
+
         int limit = req.getIntParameter(AJAXServlet.PARAMETER_LIMIT);
         limit = limit < 0 ? 10 : limit;
 
@@ -215,42 +230,38 @@ public class EmailContactHalo extends AbstractContactHalo implements HaloContact
             if (searchingExternalMailboxesIsFast()) {
                 userMailAccounts = mailAccountService.getUserMailAccounts(session.getUserId(), session.getContextId());
             } else {
-                userMailAccounts = new MailAccount[] { mailAccountService.getDefaultMailAccount(session.getUserId(), session.getContextId()) };
+                userMailAccounts = mailAccountService.getUserDefaultAndSecondaryMailAccounts(session.getUserId(), session.getContextId());
             }
+            userMailAccounts = MailAccounts.removeDeactivatedAccountsFrom(userMailAccounts);
         }
 
-        SearchTerm<?> senderTerm = generateSenderSearch(addresses);
-        SearchTerm<?> recipientTerm = generateRecipientSearch(addresses);
-        List<MailMessage> messages = new LinkedList<MailMessage>();
-        for (MailAccount mailAccount : userMailAccounts) {
-            MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = null;
-            try {
-                mailAccess = mailService.getMailAccess(session, mailAccount.getId());
-                mailAccess.connect();
-                RetrievalResult retrievees = retrieveMessages(limit, senderTerm, recipientTerm, requestedFields, headers, mailAccess);
-                messages.addAll(retrievees.inboxMessages);
-                messages.addAll(retrievees.sentMessage);
-            } finally {
-                if (mailAccess != null) {
-                    mailAccess.close(true);
+        List<MailMessage> inboxMessages = new LinkedList<MailMessage>();
+        List<MailMessage> sentMessage = new LinkedList<MailMessage>();
+        {
+            SearchTerm<?> senderTerm = generateSenderSearch(addresses);
+            SearchTerm<?> recipientTerm = generateRecipientSearch(addresses);
+            for (MailAccount mailAccount : userMailAccounts) {
+                MailAccess<? extends IMailFolderStorage, ? extends IMailMessageStorage> mailAccess = null;
+                try {
+                    mailAccess = mailService.getMailAccess(session, mailAccount.getId());
+                    mailAccess.connect();
+                    RetrievalResult retrievees = retrieveMessages(limit, senderTerm, recipientTerm, requestedFields, headers, mailAccess);
+                    inboxMessages.addAll(retrievees.inboxMessages);
+                    sentMessage.addAll(retrievees.sentMessage);
+                } finally {
+                    if (mailAccess != null) {
+                        mailAccess.close(true);
+                    }
                 }
             }
         }
 
-        Collections.sort(messages, new Comparator<MailMessage>() {
+        Collections.sort(inboxMessages, MAIL_COMPARATOR);
+        Collections.sort(sentMessage, MAIL_COMPARATOR);
 
-            @Override
-            public int compare(final MailMessage arg0, final MailMessage arg1) {
-                final Date sentDate1 = arg1.getSentDate();
-                final Date sentDate0 = arg0.getSentDate();
-                if (sentDate1 == null) {
-                    return null == sentDate0 ? 0 : -1;
-                }
-                return null == sentDate0 ? 1 : sentDate1.compareTo(sentDate0);
-            }
-        });
-
-        messages = messages.subList(0, Math.min(limit, messages.size()));
+        List<MailMessage> messages = new ArrayList<MailMessage>(limit << 1);
+        messages.addAll(inboxMessages.size() > limit ? inboxMessages.subList(0, limit) : inboxMessages);
+        messages.addAll(sentMessage.size() > limit ? sentMessage.subList(0, limit) : sentMessage);
         return new AJAXRequestResult(messages, "mail");
     }
 
